Version 0.0.2
=============

New features
------------

The function 'riser_height' was added. It calculates the exact riser height.

Enhancements
------------

TBD

Fixes
-----

TBD

Other
-----

TBD
